@@ -72,7 +72,7 @@ def cprint(color: str, string, out_file=sys.stdout):
     print(format + string + end, file=out_file)
 
 
-def get_updated_dirs(library):
+def sort_updated_dirs(library):
     update_dict = {}
     for k in library.keys():
         update_dict[library[k]["update_time"]] = k
